==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/nb.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Snittbelastning",
    "Last minute" : "Siste minutt",
    "Memory info not available" : "Minneinformasjon er ikke tilgjengelig",
    "Total" : "Totalt",
    "Current usage" : "Nåværende bruk",
    "Users" : "Brukere",
    "Groups" : "Grupper",
    "Links" : "Lenker",
    "Federated sent" : "«Forent sendt» - delingen sendt eksternt",
    "Federated received" : "«Forent mottatt» - en ekstern deling mottatt",
    "Last 24 hours" : "Siste 24 timer",
    "Last 1 hour" : "Siste time",
    "Last 5 mins" : "Siste 5 minutter",
    "Monitoring" : "Overvåker",
    "CPU load" : "CPU last",
    "Memory usage" : "Minnebruk",
    "Active users" : "Aktive brukere",
    "Shares" : "Delinger",
    "Storage" : "Lagring",
    "Users:" : "Brukere:",
    "Files:" : "Filer:",
    "PHP" : "PHP",
    "Version:" : "Versjon:",
    "Memory Limit:" : "Minnegrense:",
    "Max Execution Time:" : "Maks. kjøringstid:",
    "Upload max size:" : "Maks. opplastingstørrelse:",
    "Database" : "Database",
    "Type:" : "Type:",
    "Size:" : "Størrelse:",
    "External monitoring tool" : "Eksternt overvåkingsverktøy",
    "You can connect an external monitoring tool by using this end point: " : "Du kan koble til et eksternt overvåkingsverktøy ved å bruke følgende endepunkt:",
    "Server info" : "Tjenerinformasjon",
    "You can connect a external monitoring tool by using this end point: " : "Du kan koble til et eksternt overvåkingsverktøy ved å bruke dette endepunktet: "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/nb.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Snittbelastning",
    "Last minute" : "Siste minutt",
    "Memory info not available" : "Minneinformasjon er ikke tilgjengelig",
    "Total" : "Totalt",
    "Current usage" : "Nåværende bruk",
    "Users" : "Brukere",
    "Groups" : "Grupper",
    "Links" : "Lenker",
    "Federated sent" : "«Forent sendt» - delingen sendt eksternt",
    "Federated received" : "«Forent mottatt» - en ekstern deling mottatt",
    "Last 24 hours" : "Siste 24 timer",
    "Last 1 hour" : "Siste time",
    "Last 5 mins" : "Siste 5 minutter",
    "Copy" : "Kopier",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Ikke støttet!",
    "Monitoring" : "Overvåker",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Gir nyttig serverinformasjon, som CPU-belastning, RAM-bruk, diskbruk, antall brukere, ned mere.",
    "CPU load" : "CPU last",
    "Memory usage" : "Minnebruk",
    "Active users" : "Aktive brukere",
    "Shares" : "Delinger",
    "Storage" : "Lagring",
    "Users:" : "Brukere:",
    "Files:" : "Filer:",
    "Version:" : "Versjon:",
    "Apps installed:" : "Apper installert:",
    "Apps updates available:" : "App-oppdateringer tilgjengelig:",
    "PHP" : "PHP",
    "Memory Limit:" : "Minnegrense:",
    "Max Execution Time:" : "Maks. kjøringstid:",
    "Upload max size:" : "Maks. opplastingstørrelse:",
    "Database" : "Database",
    "Type:" : "Type:",
    "Size:" : "Størrelse:",
    "External monitoring tool" : "Eksternt overvåkingsverktøy"
},
"nplurals=2; plural=(n != 1);");
